goappdata

package module
v0.0.0-...-922f46b Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Jul 10, 2012 License: MIT Imports: 2 Imported by: 1

README

goappdata is an abstraction over the storage path for persistent app data

Documentation

Overview

Abstraction over the storage path for persistent app data

Darwin:

$HOME/Library/ApplicationSupport/<appname>

Linux/*BSD:

$HOME/.config/<appname>

Windows:

%APPDATA%/Local/<appname>

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func CreatePath

func CreatePath(appname string) (string, error)

Same as Path, but implicitly creates the folder, if it does not exist yet.

func Path

func Path(appname string) string

Returns the path to folder in which the an app with the name `appname` is supposed to store its data.

Types

This section is empty.

Jump to