Documentation
¶
Overview ¶
Abstraction over the storage path for persistent app data
Darwin:
$HOME/Library/ApplicationSupport/<appname>
Linux/*BSD:
$HOME/.config/<appname>
Windows:
%APPDATA%/Local/<appname>
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func CreatePath ¶
Same as Path, but implicitly creates the folder, if it does not exist yet.
Types ¶
This section is empty.
Click to show internal directories.
Click to hide internal directories.